import schemaUtil from 'schema-util';
import React from 'react';
import ReactDOM from 'react-dom';
import Editor from '../lib/index';
import { Switch, Select } from 'antd';

const Option = Select.Option;

require('../lib/index.less');
require('./demo.less');
const defaultSchemaList = require('./schemaList');
const schemaArray = {};

Object.keys(defaultSchemaList).map(name => {
  schemaArray[name] = defaultSchemaList[name].trim().replace(/^Object/, 'Array');
});

class Demo extends React.Component {
  constructor(props) {
    super(props);
    const schema = schemaUtil.schema(defaultSchemaList.default);
    this.state = {
      schema: schema,
      checked: false,
      type: 'default',
      data: schemaUtil.mock(schema),
      dataNext: null,
      schemaNext: schemaUtil.schema(defaultSchemaList.provinces),
    };
  }

  onChange(data, e) {
    this.setState({ data: data });
  }

  onSwitch(checked) {
    const type = this.state.type;
    const schemaText = !checked ? defaultSchemaList[type] : schemaArray[type];
    const schema = schemaUtil.schema(schemaText);
    const data = schemaUtil.mock(schema);

    if (type === 'koubei') {
      delete data.itemType1;
    }
    if (type === 'default') {
      data.text = 123;
    }

    this.setState({
      checked: checked,
      schema,
      data: data,
    });
  }

  getSelect() {
    const options = Object.keys(defaultSchemaList).map(name => <Option value={name} key={name}>{name}</Option>);
    return (
      <Select defaultValue="default" style={{ width: 120 }} onChange={this.handleChange.bind(this)}>
        {options}
      </Select>
    );
  }

  handleChange(value) {
    this.state.type = value;
    this.onSwitch(this.state.checked);
  }

  onError(errorInfo) {
    console.log(errorInfo);
  }

  render() {
    const text = !this.state.checked ? '对象' : '数组';
    const props = {
      hash: this.state.type + this.state.checked,
      value: this.state.data,
      schema: this.state.schema,
      onChange: this.onChange.bind(this),
      config: {
        excelImport: true,
      },
      onError: this.onError,
    };

    const next = Object.assign({}, props, {
      schema: this.state.schemaNext,
      value: this.state.dataNext,
      onChange: (data) => {
        this.setState({ dataNext: data });
      },
      onClick: (data) => {
        console.log('[onClick]', data)
      }
    });

    return (
      <div>
        <div className="object-title">
          <div className="object-title-item">
            <span>选择 schema 案例：{this.getSelect()}</span>
            <span>
              最外层：{text} <Switch checked={this.state.checked} onChange={this.onSwitch.bind(this)} />
            </span>
          </div>
          <a href="http://gitlab.alipay-inc.com/fengdie/schema-editor/blob/master/lib/index.js">源码地址</a>
        </div>

        <Editor {...props} />
      </div>
    );
  }
}

ReactDOM.render(<Demo />, document.querySelector('.view-box'));
