'use strict';

var _tooltip = require('antd/lib/tooltip');

var _tooltip2 = _interopRequireDefault(_tooltip);

var _icon = require('antd/lib/icon');

var _icon2 = _interopRequireDefault(_icon);

var _modal = require('antd/lib/modal');

var _modal2 = _interopRequireDefault(_modal);

var _spin = require('antd/lib/spin');

var _spin2 = _interopRequireDefault(_spin);

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

var _csv = require('../util/csv');

var _csv2 = _interopRequireDefault(_csv);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var csv = require('schema-util').csv;

var UPLOAD_STATUS = {
  loading: '正在导入 excel ...',
  error: _react2.default.createElement(
    'span',
    null,
    '\u4E0A\u4F20\u5931\u8D25'
  ),
  success: '上传成功',
  warning: _react2.default.createElement(
    'span',
    null,
    '\u4E0A\u4F20\u6210\u529F\uFF0C\u4F46\u5185\u5BB9\u6709\u9519\u8BEF'
  )
};
// 找出 date 类型的 schema key
var getDateKey = function getDateKey(schema) {
  return Object.keys(schema.properties).filter(function (key) {
    return schema.properties[key].type === 'date';
  });
};

// excel上传&下载组件，上传完成后提供onSuccess回调方法

var ExcelButton = function (_React$Component) {
  _inherits(ExcelButton, _React$Component);

  function ExcelButton() {
    _classCallCheck(this, ExcelButton);

    var _this = _possibleConstructorReturn(this, (ExcelButton.__proto__ || Object.getPrototypeOf(ExcelButton)).call(this));

    _this.handleCloseModal = function () {
      _this.setState({ uploading: false });
    };

    _this.handleUploadCsv = function (e) {
      if (_this.props.onClick) {
        _this.props.onClick({ key: 'handleUploadCsv' });
      }
      var input = e.target;
      var file = input.files.item(0);
      var schema = _this.props.schema;
      var dateKeys = getDateKey(schema);
      // 大于 100k 才有 loading 浮层
      _this.setState({
        uploading: true,
        bigFile: file.size > 100000,
        status: 'loading',
        message: ''
      });

      if (file.size > 1024 * 1024 * 3) {
        _this.setState({
          status: 'error',
          message: '无法上传超过 3M 的文件'
        });
        return;
      }

      setTimeout(function () {
        _csv2.default.read(file, _this.props.title).then(function (csvData) {
          var data = csv.read(schema, csvData);
          if (dateKeys.length) {
            data.map(function (dataItem) {
              dateKeys.forEach(function (dateKey) {
                var m = (0, _moment2.default)(dataItem[dateKey]);
                if (m.isValid()) {
                  // YYYY-MM-DD HH:mm 式数据转时间戳
                  dataItem[dateKey] = Number(m.format('x'));
                } else {
                  // 兼容科学计数转时间戳
                  var timestamp = Number(dataItem[dateKey]);
                  if (!isNaN(timestamp)) dataItem[dateKey] = timestamp;
                }
              });
              return dataItem;
            });
          }
          _this.props.onUploadSuccess(data);
          return _this.props.errorList && _this.props.errorList.length > 0;
        }).then(function (isHandleError) {
          // 处理错误
          if (isHandleError) {
            _this.setState({
              status: 'warning',
              message: _this.props.errorList.map(function (error) {
                return _react2.default.createElement(
                  'div',
                  null,
                  '\u7B2C',
                  error.index + 1,
                  '\u884C\u7684',
                  error.label,
                  '\u5B57\u6BB5\u4E0D\u7B26\u5408\u89C4\u5219\uFF1A',
                  error.errorMsg
                );
              })
            });

            return;
          }

          // 成功
          _this.setState({
            status: 'success',
            message: ''
          });

          setTimeout(function () {
            _this.setState({
              status: null,
              message: ''
            });
          }, 1000);
        }).catch(function (err) {
          _this.setState({
            status: 'error',
            message: '上传的文件内容不合法'
          });
          throw err;
        });
        input.value = '';
      });
    };

    _this.handleDownloadCsv = function () {
      if (_this.props.onClick) {
        _this.props.onClick({ key: 'handleDownloadCsv' });
      }
      var _this$props = _this.props,
          title = _this$props.title,
          schema = _this$props.schema,
          data = _this$props.data;
      // 格式化 date 数据

      if (schema.type === 'array') {
        var dateKeys = getDateKey(schema);
        if (dateKeys.length) {
          data.map(function (dataItem) {
            dateKeys.forEach(function (dateKey) {
              var m = (0, _moment2.default)(dataItem[dateKey]);
              if (m.isValid()) {
                dataItem[dateKey] = m.format('YYYY-MM-DD HH:mm');
              }
            });
            return dataItem;
          });
        }
      }
      _csv2.default.write(schema, data, title);
    };

    _this.state = {
      uploading: false,
      status: 'loading',
      message: '',
      bigFile: false
    };
    return _this;
  }

  _createClass(ExcelButton, [{
    key: 'render',
    value: function render() {
      if (this.props.rule) {
        return null;
      }
      var locale = this.props.locale;

      var model = void 0;
      var uploading = this.state.uploading;
      var bigFile = this.state.bigFile;
      if (bigFile && uploading) {
        // 如果是大文件，才显示 loading 浮层
        model = _react2.default.createElement(
          _modal2.default,
          {
            visible: uploading,
            onCancel: this.handleCloseModal,
            footer: null
          },
          _react2.default.createElement(
            'div',
            { className: 'prerelease-box release-box' },
            _react2.default.createElement(
              'div',
              { className: 'title' },
              UPLOAD_STATUS[this.state.status]
            ),
            _react2.default.createElement(
              'div',
              { className: 'content' },
              this.state.status === 'loading' ? _react2.default.createElement(_spin2.default, null) : null,
              this.state.status === 'error' && this.state.message
            )
          )
        );
      }

      return _react2.default.createElement(
        'ul',
        { className: 'item-csvdata' },
        _react2.default.createElement(
          'li',
          { onClick: this.handleDownloadCsv },
          _react2.default.createElement(_icon2.default, { type: 'download' }),
          locale.EXPORT_EXCEL
        ),
        _react2.default.createElement(
          'li',
          { className: 'item-csvdata-upload' },
          _react2.default.createElement(
            _tooltip2.default,
            { visible: ['error', 'warning'].indexOf(this.state.status) > -1, title: UPLOAD_STATUS[this.state.status] },
            _react2.default.createElement(_icon2.default, { type: 'upload' }),
            locale.IMPORT_EXCEL,
            _react2.default.createElement('input', {
              type: 'file',
              onChange: this.handleUploadCsv,
              accept: 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'
            })
          )
        ),
        model
      );
    }
  }]);

  return ExcelButton;
}(_react2.default.Component);

module.exports = ExcelButton;