'use strict';

var _popover = require('antd/lib/popover');

var _popover2 = _interopRequireDefault(_popover);

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

/*
 * 文本区块，用于描述、标题等
 *
 * @name Text
 * @function
 * @access public
 * @param { Object } props
 * @return { React.Component }
 */
var Text = function Text(props) {
  var text = props.children,
      length = props.length,
      tail = props.tail,
      tailClassName = props.tailClassName,
      showTooltip = props.showTooltip,
      textProps = _objectWithoutProperties(props, ['children', 'length', 'tail', 'tailClassName', 'showTooltip']);

  textProps.className = textProps.className ? 'text-block ' + textProps.className : 'text-block';

  if (text.length <= length || length < 0) {
    return _react2.default.createElement(
      'p',
      textProps,
      text
    );
  }

  var rest = length - tail.length;
  var displayText = rest > 0 ? text.slice(0, rest) : '';

  var tailStyle = { cursor: 'auto', paddingLeft: '2px' };
  var tailProps = { style: tailStyle, className: tailClassName };

  if (!showTooltip) {
    return _react2.default.createElement(
      'p',
      _extends({ title: text }, textProps),
      displayText,
      _react2.default.createElement(
        'span',
        tailProps,
        tail
      )
    );
  }

  var trigger = showTooltip === true ? 'click' : showTooltip;
  tailStyle.cursor = trigger === 'click' ? 'pointer' : 'help';

  var popoverProps = {
    trigger: trigger,
    content: text,
    overlayClassName: 'text-block-popover'
  };

  return _react2.default.createElement(
    'p',
    textProps,
    displayText,
    _react2.default.createElement(
      _popover2.default,
      popoverProps,
      _react2.default.createElement(
        'span',
        tailProps,
        tail
      )
    )
  );
};

Text.propTypes = {
  children: _propTypes2.default.string.isRequired,
  length: _propTypes2.default.number,
  tail: _propTypes2.default.string,
  tailClassName: _propTypes2.default.string,
  showTooltip: _propTypes2.default.oneOfType([_propTypes2.default.oneOf(['click', 'hover', 'focus']), _propTypes2.default.bool])
};

Text.defaultProps = {
  length: 60,
  tail: '...',
  tailClassName: 'more',
  showTooltip: false
};

module.exports = Text;