'use strict';

var _input = require('antd/lib/input');

var _input2 = _interopRequireDefault(_input);

var _upload = require('antd/lib/upload');

var _upload2 = _interopRequireDefault(_upload);

var _icon = require('antd/lib/icon');

var _icon2 = _interopRequireDefault(_icon);

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _copy = require('../util/copy');

var _copy2 = _interopRequireDefault(_copy);

var _uploaderValidator = require('../util/uploaderValidator');

var _uploaderValidator2 = _interopRequireDefault(_uploaderValidator);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/*
 * 上传输入框
 * 属性：
 *  name: 字段名称
 *  label: 中文标题
 *  value: 默认值
 *  meta:
 *    校验参数，Exp: width、maxWidth、height、maxHeight
 *    图片独有参数：setDefaultColorTo 指定图片上传完成后填充图片底色到目标字段
 * 方法：
 *  onChange: 图片上传成功后的回调，返回为数：
 *    target: {value: '图片地址'}
 */
var Uploader = function (_React$Component) {
  _inherits(Uploader, _React$Component);

  function Uploader() {
    _classCallCheck(this, Uploader);

    var _this = _possibleConstructorReturn(this, (Uploader.__proto__ || Object.getPrototypeOf(Uploader)).call(this));

    _this.handleSelectFile = function () {
      _this.setState({ errorMsg: '' });
    };

    _this.beforeUpload = function (file) {
      var _this$props = _this.props,
          meta = _this$props.meta,
          config = _this$props.config,
          schema = _this$props.schema;

      var isOverMaxSize = _uploaderValidator2.default.validateImageMaxSize(file, schema);
      if (!isOverMaxSize.result) {
        _this.setState({ errorMsg: isOverMaxSize.message });
        return false;
      }
      if (Math.floor(file.size) > config.uploadImgSize) {
        _this.setState({ errorMsg: '\u56FE\u7247\u5927\u5C0F\u8D85\u8FC7 ' + Math.floor(config.uploadImgSize / 1024) + 'KB' });
        return false;
      }
      if (meta && meta.setDefaultColorTo && file.type.match('image.*')) {
        var reader = new FileReader();
        reader.onloadend = function (evt) {
          if (evt.target.readyState === FileReader.DONE) {
            var img = new Image();
            img.src = evt.target.result;
          }
        };
        reader.readAsDataURL(file);
      }
      return true;
    };

    _this.handleProcess = function (info) {
      var status = info.file.status;

      switch (status) {
        case 'error':
          {
            _this.setState({
              errorMsg: info.file.response
            });
            break;
          }
        case 'done':
          {
            // 清除出错状态
            _this.setState({ errorMsg: '', success: true });
            setTimeout(function () {
              _this.setState({
                success: false
              });
            }, 2000);
            var field = _this.props.field;
            _this.props.onChange({
              value: info.file.response.data.url,
              fields: [field]
            });
            break;
          }
        default:
          {
            break;
          }
      }
    };

    _this.handleChangeImage = function (e) {
      // 清除出错状态
      _this.setState({ errorMsg: '' });
      var field = _this.props.field;

      _this.props.onChange({
        value: e.target.value,
        fields: [field]
      });
    };

    _this.state = { errorMsg: '', success: false };
    return _this;
  }

  // 点击输入框选择文件时隐藏错误提示


  // 上传的过程


  // 直接修改上传地址


  _createClass(Uploader, [{
    key: 'render',
    value: function render() {
      // 限制内容提醒
      var _props = this.props,
          data = _props.data,
          field = _props.field,
          schema = _props.schema,
          config = _props.config;

      var metaNote = null;
      var meta = schema.meta;
      var errorMsg = config.validate(data, meta, schema.type) || this.state.errorMsg;
      var cls = (0, _classnames2.default)({
        'ui-form-item': true,
        'item-image': true,
        'item-image-upload': config.imageUploadOnly
      });

      if (meta) {
        // 解决冲突
        if (meta.width && meta.maxWidth) {
          delete meta.maxWidth;
        }
        if (meta.height && meta.maxHeight) {
          delete meta.maxHeight;
        }

        // 用校验来获得提示文案
        var validateImageDimension = _uploaderValidator2.default.validateImageDimension(meta);
        var validateImageMaxSize = _uploaderValidator2.default.validateImageMaxSize({ size: Number.POSITIVE_INFINITY }, { meta: meta });
        if (!validateImageDimension.result || !validateImageMaxSize.result) {
          var both = !validateImageDimension.result && !validateImageMaxSize.result;
          metaNote = _react2.default.createElement(
            'p',
            null,
            '\u56FE\u7247\u8981\u6C42',
            validateImageDimension.message,
            both ? ',' : '',
            validateImageMaxSize.message
          );
        }
      }
      var btn = _react2.default.createElement(
        'span',
        { onClick: this.handleSelectFile },
        _react2.default.createElement(_icon2.default, { type: 'picture' }),
        config.locale.CHOOSE_IMAGE
      );
      if (this.state.success) {
        btn = _react2.default.createElement(
          'span',
          { className: 'item-image-success' },
          _react2.default.createElement(_icon2.default, { type: 'check-circle' }),
          '\u4E0A\u4F20\u6210\u529F'
        );
      }
      var preview = data ? _react2.default.createElement(
        'div',
        { className: 'item-image-preview' },
        _react2.default.createElement('div', { style: { backgroundImage: 'url(' + data + ')' } }),
        _react2.default.createElement(
          _copy2.default,
          { text: data, className: 'item-image-preview-url', description: '\u590D\u5236\u56FE\u7247\u5730\u5740' },
          _react2.default.createElement(
            'span',
            null,
            (data || '').split('/').reverse()[0]
          )
        )
      ) : null;

      // 渲染
      return _react2.default.createElement(
        'div',
        { className: cls, key: field },
        _react2.default.createElement(
          'div',
          { className: 'ui-label' },
          _react2.default.createElement(
            'span',
            { className: 'ui-label-title', title: schema.description },
            schema.description,
            meta && meta.description ? _react2.default.createElement(
              'p',
              { title: schema.meta.description },
              schema.meta.description
            ) : null,
            metaNote
          ),
          _react2.default.createElement(
            _upload2.default,
            {
              action: config.uploadApi,
              headers: config.uploadHeaders || {},
              beforeUpload: this.beforeUpload,
              onChange: this.handleProcess,
              data: meta,
              withCredentials: true,
              accept: 'image/*',
              forceAjax: true
            },
            btn
          )
        ),
        _react2.default.createElement(
          'div',
          { className: 'ui-content' },
          config.imageUploadOnly ? null : _react2.default.createElement(_input2.default, {
            size: config.size,
            defaultValue: data,
            value: data,
            onChange: this.handleChangeImage
          }),
          errorMsg && errorMsg !== '' ? _react2.default.createElement(
            'div',
            { className: 'item-image-error' },
            _react2.default.createElement(_icon2.default, { type: 'close-circle' }),
            errorMsg
          ) : null,
          config.imageUploadOnly ? preview : null
        )
      );
    }
  }]);

  return Uploader;
}(_react2.default.Component);

module.exports = Uploader;