'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

/* eslint no-bitwise: ["error", { "allow": ["&"] }] */

var csv = require('schema-util').csv;
exports.read = function (file, title) {
  return new Promise(function (resolve, reject) {
    var reader = new FileReader();
    reader.onload = function (e) {
      var data = e.target.result;
      var workbook = XLSX.read(data, { type: 'binary' });
      var result = void 0;
      // 如果有多个, 则需要匹配名字
      if (workbook.SheetNames.length > 1) {
        workbook.SheetNames.forEach(function (sheetName) {
          if (sheetName === title) {
            result = XLSX.utils.sheet_to_json(workbook.Sheets[sheetName], { header: 1 });
            return false;
          }
        });
      } else if (workbook.SheetNames.length === 1) {
        // 否则取第一个即可
        result = XLSX.utils.sheet_to_json(workbook.Sheets[workbook.SheetNames[0]], { header: 1 });
      }

      if (result) {
        var convertBoolean = function convertBoolean(val) {
          if (typeof val === 'string') {
            if (val.toUpperCase() === 'TRUE') {
              return true;
            } else if (val.toUpperCase() === 'FALSE') {
              return false;
            }
          }
          return val;
        };
        var getValue = function getValue(row) {
          return row.map(function (item) {
            return convertBoolean(item);
          });
        };
        resolve(result.map(getValue));
      } else {
        reject('no sheet');
      }
    };
    reader.readAsBinaryString(file);
  });
};

// todo: 可以直接将 json 转成 xlsx 格式，不需要中间转成 csv，但在外部接口也需同步修改
exports.write = function (schema, datas, title) {
  function sheet_from_array_of_arrays(data) {
    var ws = {};
    var range = { s: { c: 10000000, r: 10000000 }, e: { c: 0, r: 0 } };
    for (var R = 0; R !== data.length; ++R) {
      for (var C = 0; C !== data[R].length; ++C) {
        if (range.s.r > R) range.s.r = R;
        if (range.s.c > C) range.s.c = C;
        if (range.e.r < R) range.e.r = R;
        if (range.e.c < C) range.e.c = C;
        var cell = { v: data[R][C] };
        if (cell.v == null) continue;
        var cell_ref = XLSX.utils.encode_cell({ c: C, r: R });

        if (typeof cell.v === 'number') cell.t = 'n';else if (typeof cell.v === 'boolean') cell.t = 'b';else if (_typeof(cell.v) === 'object') {
          // Object 转成 字符串
          cell.t = 's';
          cell.v = JSON.stringify(cell.v);
        } else cell.t = 's';

        ws[cell_ref] = cell;
      }
    }
    if (range.s.c < 10000000) ws['!ref'] = XLSX.utils.encode_range(range);
    return ws;
  }

  var data = void 0;
  var ws_name = title;
  // 抽奖的特殊构造 success 和 error 的数据
  if (schema.lottery) {
    var successCsv = [];
    if (schema.properties.success) {
      successCsv = [['success']].concat(csv(schema.properties.success, datas.success));
    }
    var errorCsv = [];
    if (schema.properties.error) {
      errorCsv = [['error']].concat(csv(schema.properties.error, datas.error));
    }
    data = successCsv.concat(errorCsv);
  } else {
    data = csv(schema, datas);
  }

  function Workbook() {
    if (!(this instanceof Workbook)) return new Workbook();
    this.SheetNames = [];
    this.Sheets = {};
  }

  var wb = new Workbook();
  var ws = sheet_from_array_of_arrays(data);

  /* add worksheet to workbook */
  wb.SheetNames.push(ws_name);
  wb.Sheets[ws_name] = ws;
  var wbout = XLSX.write(wb, { bookType: 'xlsx', bookSST: true, type: 'binary' });

  function s2ab(s) {
    var buf = new ArrayBuffer(s.length);
    var view = new Uint8Array(buf);
    for (var i = 0; i !== s.length; ++i) {
      view[i] = s.charCodeAt(i) & 0xFF;
    }
    return buf;
  }

  saveAs(new Blob([s2ab(wbout)], { type: 'application/octet-stream' }), title + '.xlsx');
};