import React from 'react';
import classnames from 'classnames';
import { Icon, Tooltip } from 'antd';
import { SortableElement, SortableHandle } from 'react-sortable-hoc';

import ObjectField from './object';
import getArrayTitle from '../util/getArrayTitle';

const DragHandle = SortableHandle(props => {
  const cls = classnames('row-drag', {
    'row-drag-disable': (props.disable === true),
  });
  return (<a className={cls} />);
});

class ArrayItem extends React.Component {
  handlePreventDefault = ev => {
    ev.stopPropagation();
    ev.preventDefault();
  }

  render() {
    const { field, itemLength, isActived, schema, data, deleteItem, copyItem, toggleItem, config } = this.props;
    const { minLength, maxLength } = Object.assign({}, { minLength: null, maxLength: null }, { ...schema.meta });
    const boxCls = classnames('row', { active: isActived });

    const rootData = config ? config.rootData : {};
    const title = getArrayTitle(data, schema, rootData);
    const panel = isActived
      ? <ObjectField
        schema={schema}
        data={data}
        field={field}
        onChange={this.props.onChange}
        config={config}
      />
      : null;

    return (
      <div key={field} className={boxCls}>
        <div className="title" onClick={toggleItem(field)}>
          <div className="row-title">
            <DragHandle disable={isActived} />
            <span>{title}</span>
          </div>
          <div className="row-options">
            {
              isActived
                ? null
                : <span className="row-edit" onClick={toggleItem(field)}><Icon type="edit" /></span>
            }

            {
              /* 数组长度 >= 最大限制时不显示复制按钮 */
              maxLength && itemLength >= maxLength
                ? <Tooltip overlayClassName="schema-editor-tips" placement="top" title={`最多能增加${maxLength}条数据`}>
                  <span className="row-copy row-copy-disable" onClick={this.handlePreventDefault}>
                    <Icon type="copy" />
                  </span>
                </Tooltip>
                : <span className="row-copy" onClick={copyItem}>
                  <Icon type="copy" />
                </span>
            }
            {
              /* 数组长度 <= 最小限制时不显示删除按钮 */
              minLength && itemLength <= minLength
                ? <Tooltip overlayClassName="schema-editor-tips" placement="top" title={`最少需要保留${minLength}条数据`}>
                  <span className="row-delete row-delete-disable" onClick={this.handlePreventDefault}>
                    <Icon type="delete" />
                  </span>
                </Tooltip>
                : <span className="row-delete" onClick={deleteItem}>
                  <Icon type="delete" />
                </span>
            }
          </div>
        </div>
        <div className="results" ref={`panel-${field}`}>{panel}</div>
      </div>
    );
  }
}

export default SortableElement(ArrayItem);
