import React from 'react';
import Text from './text';
import { Popover } from 'antd';
import { SketchPicker } from 'react-color';
const tinyColor = require('react-color/modules/tinycolor2');

/**
 * 颜色输入框
 *  - 输入格式
 *   - 支持 hex, rgb, rgba 等各种格式输入
 *   - hex 格式输入，带不带 `#` 都支持
 *  - 存储
 *   - 使用 rgb(a) 格式存储，支持 alpha 通道
 *   - 初始化时支持各种格式输入
 *
 * @access public
 * @param { Object } props props
 * @return { ColorPicker } color-picker component
 */
module.exports = ({ field, schema, onChange, data }) => {
  const colorString = data || 'rgba(0, 0, 0, 1)';

  const popoverProps = {
    overlayClassName: 'color-picker',
    placement: 'bottom',
    trigger: 'click',
    content: (
      <SketchPicker
        presetColors={ [] }
        color={ tinyColor(colorString) }
        onChange={ ({ rgb }) => onChange({
          value: tinyColor(rgb).toRgbString(),
          fields: [ field ],
        }) }
      />
    ),
  };

  const description = schema.meta && schema.meta.description
    ? <Text showTooltip>{ schema.meta.description }</Text>
    : null;

  return (
    <div className="ui-form-item field-color" key={ field }>
      <div className="ui-label" title={ field }>
        <span className="ui-label-title" title={ schema.description }>{ schema.description }</span>
        { description }
      </div>
      <div className="ui-content">
        <Popover { ...popoverProps }>
          <div className="swatch">
            <i className="color" style={ { background: colorString } } />
            <span className="color-string" >{ colorString }</span>
          </div>
        </Popover>
      </div>
    </div>
  );
};
