import React from 'react';
const moment = require('moment');
import Text from './text';

import { DatePicker } from 'antd';

class DateField extends React.Component {
  onChange = date => {
    const field = this.props.field;
    // - 统一返回时间戳，例如 1462421539675
    const value = (new Date(date)).getTime();
    this.props.onChange({ value, fields: [ field ] });
  }

  render() {
    const { schema, data, field } = this.props;
    const label = schema.description;
    const name = field;
    // support number or 'number' string or 'YYYY-mm-dd HH:mm' date string
    const dt = new Date(+data || data);
    const date = isNaN(dt) ? new Date() : dt;

    const description = schema.meta && schema.meta.description
      ? <Text showTooltip>{ schema.meta.description }</Text>
      : null;

    return (
      <div className="ui-form-item field-string" key={name}>
        <div className="ui-label" title={name}>
          <span className="ui-label-title" title={label}>{label}</span>
          { description }
        </div>
        <div className="ui-content">
          <DatePicker
            showTime
            dropdownClassName="schema-editor-data-picker"
            format="YYYY-MM-DD HH:mm"
            onChange={this.onChange} value={moment(date)} />
        </div>
      </div>
    );
  }
}

module.exports = DateField;
