import React from 'react';
import Text from './text';
import { Select } from 'antd';
const Option = Select.Option;

class Enums extends React.Component {

  handleSelect = value => {
    const field = this.props.field;
    this.props.onChange({ value, fields: [ field ] });
  }

  getItems() {
    const { schema, parentData, config } = this.props;
    let source = schema.meta ? schema.meta.source : null;
    if (source) {
      let rootData = parentData;

      const ROOT = '$root.';
      if (source.indexOf(ROOT) === 0) {
        rootData = config.rootData;
        if (Array.isArray(rootData) && config.paths.length) {
          rootData = rootData[config.paths[0]];
        }
        source = source.slice(ROOT.length);
      }

      if (Array.isArray(rootData[source])) {
        return rootData[source];
      }
    }
    return schema.items;
  }

  getSelect() {
    const { data, schema } = this.props;
    const items = this.getItems();

    // 是否是多选
    const multiple = !!((schema.meta && schema.meta.multiple === true));
    // 被选中的项的描述，如果没有，则选第一个
    let selectValueName = multiple ? [] : undefined;

    const values = {};
    const options = items.map((item, i) => {
      const val = item.value;
      // 清空重复的数据
      if (values[val]) {
        return null;
      }

      values[val] = true;

      if ([].concat(data).indexOf(item.value) !== -1) {
        if (multiple) {
          selectValueName.push(item.value);
        } else {
          selectValueName = item.value;
        }
      }
      return <Option value={item.value} key={i}>{item.label}</Option>;
    }).filter(o => o);

    const modeProps = multiple ? {
      mode: 'multiple',
    } : {};

    // 下拉选择器，当选项数量超过 5 个的时候显示过滤框
    return (
      <Select
        allowClear
        showSearch
        dropdownClassName="schema-editor-select-option"
        placeholder="请输入关键字进行筛选"
        optionFilterProp="children"
        notFoundContent="无法找到"
        style={{ width: '100%' }}
        value={selectValueName}
        onChange={this.handleSelect}
        {...modeProps}
      >
        {options}
      </Select>
    );
  }

  render() {
    const { schema } = this.props;

    const description = schema.meta && schema.meta.description
      ? <Text showTooltip>{ schema.meta.description }</Text>
      : null;

    return (
      <div className="url-input ui-form-item">
        <div className="ui-label">
          <span className="ui-label-title" title={schema.description}>{schema.description}</span>
          { description }
        </div>
        <div className="ui-content">
          {this.getSelect()}
        </div>
      </div>
    );
  }
}

module.exports = Enums;
