import React from 'react';
import { Popover, Upload, Form, Input, Icon } from 'antd';
const FormItem = Form.Item;

// 支持的类型
const fileContentTypes = [
  'text/html',
  'audio/mpeg',
];

class File extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      errorMsg: '',
      fileName: '',
    };
  }

  readFile(file) {
    const reader = new FileReader();
    const self = this;
    const field = this.props.field;

    reader.onloadend = function(evt) {
      if (evt.target.readyState === FileReader.DONE) {
        const html = `${evt.target.result}`;
        self.props.onChange({ value: html, fields: [ field ] });
      }
    };
    reader.onerror = function(e) {
      self.setState({
        errorMsg: `文件读取错误 ${e}`,
      });
    };
    reader.readAsText(file);

    this.setState({
      fileName: `已选择 ${file.name}`,
    });
  }

  beforeUpload = file => {
    if (fileContentTypes.indexOf(file.type) === -1) {
      this.setState({
        errorMsg: '不支持该类型的文件',
      });
    } else if (file.type === 'text/html') {
      this.setState({
        errorMsg: '',
      });
      this.readFile(file);
    }
    return false;
  }

  handlerProcess = info => {
    const status = info.file.status;

    switch (status) {
      case 'error': {
        this.setState({
          errorMsg: info.file.response,
        });
        break;
      }
      case 'done': {
        // 清除出错状态
        this.setState({ errorMsg: '', success: true });
        setTimeout(() => {
          this.setState({
            success: false,
          });
        }, 2000);
        const field = this.props.field;
        this.props.onChange({
          value: info.file.response.url,
          fields: [ field ],
        });
        break;
      }
      default: {
        break;
      }
    }
  }
  handleFileNameChange = () => {}
  render() {
    // 活动创建异常时的提示信息
    const errorMsg = this.state.errorMsg;
    const fileName = this.state.fileName;
    const { schema, config } = this.props;

    return (
      <div className="ui-form-item item-file">
        <div className="ui-label">
          <span className="ui-label-title" title={schema.description}>{schema.description}</span>
        </div>
        <div className="ui-content">
          <Popover
            content={errorMsg}
            placement="top"
            visible={!!errorMsg}
          >
            <FormItem
              hasFeedback
              validateStatus={errorMsg === '' ? '' : 'error'}
            >
              <Input size={config.size} value={fileName} onChange={this.handleFileNameChange}/>
            </FormItem>
          </Popover>
          <Upload
            action="/api/upload"
            onChange={this.handlerProcess}
            beforeUpload={this.beforeUpload}
          >
            <a href="#nowhere">
              <Icon type="upload" />{schema.description}
            </a>
          </Upload>
        </div>
      </div>
    );
  }
}

module.exports = File;
