// 这里在服务器渲染的时候，需要调用react
import React from 'react';
import schemaUtil from 'schema-util';
import Textfield from './textfield';
import Color from './color';
import Uploader from './uploader';
import Switch from './switch';
import RichText from './rich-text';
import DateField from './date';
import Enum from './enum';
import TextArea from './textarea';
import NumberFiled from './number';
import FileField from './file';

import { addKey } from '../util/index';

function getItem(type, props) {
  const config = props.config;
  // 自定义类型
  if (config.fieldMap[type]) {
    return React.createElement(config.fieldMap[type], props);
  }

  // 根据不同的输入类型选择对应的处理模块
  switch (type) {
    case 'image':
      return <Uploader {...props} />;
    case 'boolean':
      return <Switch {...props} />;
    case 'richtext':
      return <RichText {...props} />;
    case 'text':
      return <TextArea {...props} />;
    case 'date':
      return <DateField {...props} />;
    case 'color':
      return <Color {...props} />;
    case 'enum':
      return <Enum {...props} />;
    case 'number':
      return <NumberFiled {...props} />;
    case 'file':
      return <FileField {...props} />;
    case 'box':
      // box类型不渲染
      return null;
    case 'component':
      // 凤蝶 2.5 后不需要 component 类型
      return null;
    case 'object': {
      const ObjectField = require('./object');
      return <ObjectField {...props} />;
    }
    case 'array': {
      const ArrayField = require('./array').default;
      let data = props.data;
      if (data && !Array.isArray(data)) {
        data = addKey(schemaUtil.mock(props.schema));
      }
      return <ArrayField {...props} data={ data } />;
    }
    default: {
      return <Textfield {...props} />;
    }
  }
}

module.exports = {
  getItem,
};
