import React from 'react';
import schemaUtil from 'schema-util';

import Text from './text';
import { InputNumber, Form } from 'antd';
const FormItem = Form.Item;

import classnames from 'classnames';

// 数值输入框
class NumberField extends React.Component {

  handleChange = value => {
    const field = this.props.field;
    // 兼容以前，返回 string 类型
    this.props.onChange({ value, fields: [ field ] });
  }

  render() {
    const { data, schema, field, config } = this.props;
    const mockData = schemaUtil.mock(this.props.schema);
    const meta = schema.meta || {};
    const actData = isNaN(data) ? mockData : data;
    const errorMsg = config.validate(actData, schema.meta, schema.type);

    const cls = classnames({
      'ui-form-item': true,
      'field-string': true,
      'ui-form-item-error': errorMsg !== '',
    });

    const description = meta.description
      ? <Text showTooltip>{ schema.meta.description }</Text>
      : null;

    return (
      <div className={cls} key={field}>
        <div className="ui-label">
          <span className="ui-label-title" title={schema.description}>{schema.description}</span>
          { description }
        </div>
        <div className="ui-content">
          <FormItem
            hasFeedback
            help={errorMsg}
            validateStatus={errorMsg === '' ? '' : 'error'}
          >
            <InputNumber min={meta.min} max={meta.max}
              size={config.size}
              value={actData}
              step={meta.step}
              onChange={this.handleChange} />
          </FormItem>
        </div>
      </div>
    );
  }
}

module.exports = NumberField;
