import React from 'react';
import Text from './text';
const xss = require('xss');

const toolbarGroups = [
  { name: 'clipboard', groups: [ 'clipboard', 'undo' ] },
  { name: 'editing', groups: [ 'find', 'selection' ] },
  { name: 'links' },
  { name: 'insert' },
  { name: 'forms' },
  { name: 'tools' },
  { name: 'document', groups: [ 'mode', 'document', 'doctools' ] },
  { name: 'others' },
  { name: 'basicstyles', groups: [ 'basicstyles', 'cleanup' ] },
  { name: 'paragraph', groups: [ 'list', 'indent', 'blocks', 'align', 'bidi' ] },
  { name: 'styles' },
  { name: 'colors' },
  { name: 'about' },
];

const toolbar = [
  { name: 'clipboard', items: [ 'PasteText', 'PasteFromWord', '-', 'Undo', 'Redo' ] },
  { name: 'editing', items: [ ] },
  { name: 'links', items: [ 'Link', 'Unlink', 'Anchor' ] },
  { name: 'insert', items: [ 'Image' ] },
  { name: 'tools', items: [ 'Maximize' ] },
  { name: 'document', items: [ ] },
  { name: 'colors', items: [ 'TextColor' ] },
  { name: 'basicstyles', items: [ 'Bold', 'Italic', 'Strike', '-', 'RemoveFormat' ] },
  { name: 'paragraph', items: [ 'NumberedList', 'BulletedList', 'JustifyLeft', 'JustifyCenter', 'JustifyRight' ] },
  { name: 'styles', items: [ 'Format' ] },
];

/**
 * 富文本输入框
 */
class RichText extends React.Component {
  constructor() {
    super();
    this.customXSS = new xss.FilterXSS({
      whiteList: {
        a: [ 'target', 'href', 'title', 'style' ],
        abbr: [ 'title' ],
        address: [],
        area: [ 'shape', 'coords', 'href', 'alt' ],
        article: [],
        aside: [],
        audio: [ 'autoplay', 'controls', 'loop', 'preload', 'src' ],
        b: [ 'style' ],
        bdi: [ 'dir' ],
        bdo: [ 'dir' ],
        big: [],
        blockquote: [ 'cite' ],
        br: [],
        caption: [],
        center: [],
        cite: [],
        code: [],
        col: [ 'align', 'valign', 'span', 'width' ],
        colgroup: [ 'align', 'valign', 'span', 'width' ],
        dd: [],
        del: [ 'datetime' ],
        details: [ 'open' ],
        div: [ 'style' ],
        dl: [],
        dt: [],
        em: [],
        font: [ 'color', 'size', 'face', 'style' ],
        footer: [],
        h1: [ 'style' ],
        h2: [ 'style' ],
        h3: [ 'style' ],
        h4: [ 'style' ],
        h5: [ 'style' ],
        h6: [ 'style' ],
        header: [ 'style' ],
        hr: [],
        i: [],
        img: [ 'src', 'alt', 'title', 'width', 'height', 'style' ],
        ins: [ 'datetime' ],
        li: [],
        mark: [],
        nav: [],
        ol: [],
        p: [ 'style' ],
        pre: [],
        s: [],
        section: [],
        small: [],
        span: [ 'style' ],
        sub: [],
        sup: [],
        strong: [ 'style' ],
        table: [ 'width', 'border', 'align', 'valign' ],
        tbody: [ 'align', 'valign' ],
        td: [ 'width', 'rowspan', 'colspan', 'align', 'valign' ],
        tfoot: [ 'align', 'valign' ],
        th: [ 'width', 'rowspan', 'colspan', 'align', 'valign' ],
        thead: [ 'align', 'valign' ],
        tr: [ 'rowspan', 'align', 'valign' ],
        tt: [],
        u: [],
        ul: [],
        video: [ 'autoplay', 'controls', 'loop', 'preload', 'src', 'height', 'width' ],
      },
      css: {
        whiteList: {
          width: true,
          height: true,
          color: true,
          'font-size': true,
          'text-align': true,
          'text-decoration': true,
        },
      },
    });

    this.richTextRef = React.createRef();
    this.state = { EDITOR: null };
  }

  componentDidMount() {
    const config = this.props.config;
    const self = this;
    // 如果 window.CKEDITOR 已经存在,则不进行重复加载，直接生成新的 CKEDITOR
    if (window.CKEDITOR) {
      createRichText();
    } else {
      const url = 'https://a.alipayobjects.com/g/fengdie/ckeditor/4.5.31/ckeditor.js';
      const script = require('scriptjs');
      script(url, function() {
        richTextConfig();
        createRichText();
      });
    }

    // 初始化时对富文本框的样式进行设定
    function richTextConfig() {
      const CKEDITOR = window.CKEDITOR;
      CKEDITOR.config.toolbarGroups = toolbarGroups;
      CKEDITOR.config.toolbar = toolbar;

      CKEDITOR.config.height = 350;
      CKEDITOR.config.width = 'auto';
      CKEDITOR.config.fontFamily = '"Helvetica Neue",Helvetica,STHeiTi,sans-serif';
      // contentsCss: 给 CKEDITOR 的 iframe 编辑区的 css 样式
      // removeDialogTabs: 移除部分小组件的小标签，例如上传功能的高级和链接 tab 里
      CKEDITOR.config.contentsCss = [
        'https://os.alipayobjects.com/rmsportal/XCdqKNiTHAdufcg.css',
        // TODO 这里需要修改下，暂时用这里的地址吧，蜻蜓没法传一个文件
        'https://os.alipayobjects.com/rmsportal/DAOmvwmFHmiGbyW.css',
      ];

      CKEDITOR.config.allowedContent = true;
      CKEDITOR.config.removeDialogTabs = 'image:advanced;image:Link;link:advanced';
    }

    // 初始化富文本框
    function createRichText() {
      const CKEDITOR = window.CKEDITOR;
      const CKEditorName = CKEDITOR.replace(
        self.richTextRef.current, {
          customConfig: '',
          extraPlugins: 'uploadimage',
          filebrowserImageUploadUrl: config.uploadApiForRichText,
        }
      ).name;
      const EDITOR = CKEDITOR.instances[CKEditorName];

      EDITOR.on('change', function(e) {
        // 这里的换行符会导致nunjucks解析报错，所以需要自己手动筛选掉
        const html = e.editor.getData().replace(/[\n\r]/g, '');
        const field = self.props.field;
        self.props.onChange({ value: html, fields: [ field ] });
      });

      self.setState({
        EDITOR,
      });
    }
  }

  render() {
    const { schema, field, data, modified } = this.props;
    const xssFilterData = this.customXSS.process(data);

    // 使用描述
    const description = schema.meta && schema.meta.description
      ? <Text showTooltip>{ schema.meta.description }</Text>
      : null;

    // 如果已经加载，则文本框更新为新的内容
    const EDITOR = this.state.EDITOR;
    if (EDITOR && !modified) {
      // 保存成功后，回显数据库最新的内容
      EDITOR.setData(xssFilterData, {
        internal: true,
      });
    }

    return (
      <div className={'ui-form-item field-string'} key={field}>
        <div className="ui-label">
          <span className="ui-label-title" title={schema.description || '富文本'}>{schema.description || '富文本'}</span>
          { description }
        </div>
        <div className="rich-text" ref={ this.richTextRef } dangerouslySetInnerHTML={{ __html: xssFilterData }} />
      </div>
    );
  }
}

module.exports = RichText;
