import React from 'react';
import { Popover } from 'antd';
import PropTypes from 'prop-types';

/*
 * 文本区块，用于描述、标题等
 *
 * @name Text
 * @function
 * @access public
 * @param { Object } props
 * @return { React.Component }
 */
const Text = props => {
  const {
    children: text,
    length,
    tail,
    tailClassName,
    showTooltip,
    ...textProps
  } = props;

  textProps.className = textProps.className
    ? `text-block ${textProps.className}`
    : 'text-block';

  if (text.length <= length || length < 0) {
    return <p { ...textProps }>{ text }</p>;
  }

  const rest = length - tail.length;
  const displayText = rest > 0 ? text.slice(0, rest) : '';

  const tailStyle = { cursor: 'auto', paddingLeft: '2px' };
  const tailProps = { style: tailStyle, className: tailClassName };

  if (!showTooltip) {
    return (
      <p title={ text } { ...textProps }>
        { displayText }
        <span { ...tailProps }>{ tail }</span>
      </p>
    );
  }

  const trigger = showTooltip === true ? 'click' : showTooltip;
  tailStyle.cursor = trigger === 'click' ? 'pointer' : 'help';

  const popoverProps = {
    trigger,
    content: text,
    overlayClassName: 'text-block-popover',
  };

  return (
    <p { ...textProps }>
      { displayText }
      <Popover { ...popoverProps }>
        <span { ...tailProps }>
          { tail }
        </span>
      </Popover>
    </p>
  );
};

Text.propTypes = {
  children: PropTypes.string.isRequired,
  length: PropTypes.number,
  tail: PropTypes.string,
  tailClassName: PropTypes.string,
  showTooltip: PropTypes.oneOfType([
    PropTypes.oneOf([ 'click', 'hover', 'focus' ]),
    PropTypes.bool,
  ]),
};

Text.defaultProps = {
  length: 60,
  tail: '...',
  tailClassName: 'more',
  showTooltip: false,
};

module.exports = Text;
