import React from 'react';
import Text from './text';
import { Input, Form } from 'antd';
const FormItem = Form.Item;

// 文本输入框
class Textarea extends React.Component {

  onChange = e => {
    const field = this.props.field;
    const value = e.target.value;
    this.props.onChange({ value, fields: [ field ] });
  }

  render() {
    const { field, data, schema, config } = this.props;
    const meta = schema.meta;
    const maxLength = meta ? meta.maxLength : null;

    const validate = config.validate;
    const errorMsg = validate(data, schema.meta, schema.type);

    const description = meta && meta.description
      ? <Text showTooltip>{ schema.meta.description }</Text>
      : null;

    // 渲染
    return (
      <div className="ui-form-item field-string" key={field}>
        <div className="ui-label">
          <span className="ui-label-title" title={schema.description}>{schema.description}</span>
          { description }
        </div>
        <div className="ui-content">
          <FormItem
            hasFeedback
            help={errorMsg}
            validateStatus={errorMsg === '' ? '' : 'error'}
          >
            <Input.TextArea
              autosize={{ minRows: 3, maxRows: 6 }}
              onChange={this.onChange}
              value={data}
              maxLength={maxLength}
            />
          </FormItem>
        </div>
      </div>
    );
  }
}

module.exports = Textarea;
