import React from 'react';
import Text from './text';
import { Input, Form } from 'antd';
const FormItem = Form.Item;

import classnames from 'classnames';

// 文本输入框
class Textfield extends React.Component {
  constructor() {
    super();
    this.state = {
      errorMsg: '',
    };
  }

  onChange = e => {
    const value = e.target.value;
    const field = this.props.field;
    this.props.onChange({ value, fields: [ field ] });
  }

  onBlur = e => {
    const value = e.target.value;
    // 数据 trim
    const data = this.props.data.trim();
    if (data !== value) {
      const field = this.props.field;
      this.props.onChange({ value: data, fields: [ field ] });
    }
  }

  render() {
    const { field, schema, config, data } = this.props;
    const validate = config.validate;
    const errorMsg = validate(data, schema.meta, schema.type);

    const cls = classnames({
      'ui-form-item': true,
      'field-string': true,
      'ui-form-item-error': errorMsg !== '',
    });

    const description = schema.meta && schema.meta.description
      ? <Text showTooltip>{ schema.meta.description }</Text>
      : null;

    // 渲染
    return (
      <div className={cls} key={field}>
        <div className="ui-label">
          <span className="ui-label-title" title={schema.description}>{schema.description}</span>
          { description }
        </div>
        <div className="ui-content">
          <FormItem
            hasFeedback
            help={errorMsg}
            validateStatus={errorMsg === '' ? '' : 'error'}
          >
            <Input
              size={config.size}
              placeholder={this.props.placeholder}
              value={data}
              onChange={this.onChange}
              onBlur={this.onBlur}
            />
          </FormItem>
        </div>
      </div>
    );
  }
}

module.exports = Textfield;
