/* eslint no-bitwise: ["error", { "allow": ["&"] }] */

const csv = require('schema-util').csv;
exports.read = function(file, title) {
  return new Promise(function(resolve, reject) {
    const reader = new FileReader();
    reader.onload = function(e) {
      const data = e.target.result;
      const workbook = XLSX.read(data, { type: 'binary' });
      let result;
      // 如果有多个, 则需要匹配名字
      if (workbook.SheetNames.length > 1) {
        workbook.SheetNames.forEach(function(sheetName) {
          if (sheetName === title) {
            result = XLSX.utils.sheet_to_json(workbook.Sheets[sheetName], { header: 1 });
            return false;
          }
        });
      } else if (workbook.SheetNames.length === 1) {
        // 否则取第一个即可
        result = XLSX.utils.sheet_to_json(workbook.Sheets[workbook.SheetNames[0]], { header: 1 });
      }

      if (result) {
        const convertBoolean = val => {
          if (typeof val === 'string') {
            if (val.toUpperCase() === 'TRUE') {
              return true;
            } else if (val.toUpperCase() === 'FALSE') {
              return false;
            }
          }
          return val;
        };
        const getValue = row => row.map(item => convertBoolean(item));
        resolve(result.map(getValue));
      } else {
        reject('no sheet');
      }
    };
    reader.readAsBinaryString(file);
  });
};

// todo: 可以直接将 json 转成 xlsx 格式，不需要中间转成 csv，但在外部接口也需同步修改
exports.write = function(schema, datas, title) {
  function sheet_from_array_of_arrays(data) {
    const ws = {};
    const range = { s: { c: 10000000, r: 10000000 }, e: { c: 0, r: 0 } };
    for (let R = 0; R !== data.length; ++R) {
      for (let C = 0; C !== data[R].length; ++C) {
        if (range.s.r > R) range.s.r = R;
        if (range.s.c > C) range.s.c = C;
        if (range.e.r < R) range.e.r = R;
        if (range.e.c < C) range.e.c = C;
        const cell = { v: data[R][C] };
        if (cell.v == null) continue;
        const cell_ref = XLSX.utils.encode_cell({ c: C, r: R });

        if (typeof cell.v === 'number') cell.t = 'n';
        else if (typeof cell.v === 'boolean') cell.t = 'b';
        else if (typeof cell.v === 'object') {
          // Object 转成 字符串
          cell.t = 's';
          cell.v = JSON.stringify(cell.v);
        } else cell.t = 's';

        ws[cell_ref] = cell;
      }
    }
    if (range.s.c < 10000000) ws['!ref'] = XLSX.utils.encode_range(range);
    return ws;
  }

  let data;
  const ws_name = title;
  // 抽奖的特殊构造 success 和 error 的数据
  if (schema.lottery) {
    let successCsv = [];
    if (schema.properties.success) {
      successCsv = [[ 'success' ]].concat(csv(schema.properties.success, datas.success));
    }
    let errorCsv = [];
    if (schema.properties.error) {
      errorCsv = [[ 'error' ]].concat(csv(schema.properties.error, datas.error));
    }
    data = successCsv.concat(errorCsv);
  } else {
    data = csv(schema, datas);
  }

  function Workbook() {
    if (!(this instanceof Workbook)) return new Workbook();
    this.SheetNames = [];
    this.Sheets = {};
  }

  const wb = new Workbook();
  const ws = sheet_from_array_of_arrays(data);

  /* add worksheet to workbook */
  wb.SheetNames.push(ws_name);
  wb.Sheets[ws_name] = ws;
  const wbout = XLSX.write(wb, { bookType: 'xlsx', bookSST: true, type: 'binary' });

  function s2ab(s) {
    const buf = new ArrayBuffer(s.length);
    const view = new Uint8Array(buf);
    for (let i = 0; i !== s.length; ++i) {
      view[i] = s.charCodeAt(i) & 0xFF;
    }
    return buf;
  }

  saveAs(new Blob([ s2ab(wbout) ], { type: 'application/octet-stream' }), `${title}.xlsx`);
};
