/**
 * 对外暴露的数据输入输出 API ，通过 __SCHEMA_EDITOR_DEV_TOOL 来操作
 *
 * ### exportData(uid:? string)
 *
 * 导出 uid 对应的 editor 的数据，如果 uid 为空，那么找最后一个。uid 通过
 * editor 最外层 div 的 data-schema-uid 属性获得。
 *
 * ### importData(data: object, uid?: string)
 *
 * 导入数据，uid 默认为最后一个 editor
 */
const store = { active: null };
const DevTool = {
  importData: (data, uid) => {
    uid = uid || store.active;
    store[uid].importData(data);
  },
  exportData: uid => {
    uid = uid || store.active;
    return store[uid].exportData();
  },
};

const addDevToolApi = function(uid, api) {
  store[uid] = api;
  store.active = uid;
};

const removeDevToolApi = uid => delete store[uid];

global.__SCHEMA_EDITOR_DEV_TOOL = DevTool;

export { DevTool, addDevToolApi, removeDevToolApi };
