import moment from 'moment';
export default function(data, schema, rootData) {
  // 查找顺序，title -> name -> 第一个元素
  // 展示，其他折叠起来
  let showKey;

  // 指定 key 展示
  if (schema.meta && schema.meta.showKey) {
    showKey = schema.meta.showKey;
    return data[showKey];
  }

  if (data.title) {
    showKey = 'title';
  } else if (data.name) {
    showKey = 'name';
  } else {
    showKey = Object.keys(data)[0];
  }

  if (!schema.properties[showKey]) {
    showKey = Object.keys(schema.properties)[0];
  }

  const showKeyType = schema.properties[showKey].type;
  if (typeof data[showKey] === 'object') {
    //  字段类型为 object/array/box 等
    return schema.description + (data.__key || '');
  } else if (showKeyType === 'enum') {
    let showKeyItems = schema.properties[showKey].items || [];
    let source = schema.properties[showKey].meta ? schema.properties[showKey].meta.source : null;
    if (source && showKeyItems.length === 0 && rootData) {
      const ROOT = '$root.';
      if (source.indexOf(ROOT) === 0) {
        source = source.slice(ROOT.length);
        if (rootData[source]) {
          showKeyItems = rootData[source];
        }
      }
    }

    const val = data[showKey];
    const selectedItem = showKeyItems.filter(o => o.value === val)[0];
    return selectedItem ? selectedItem.label : val;
  } else if (showKeyType === 'date') {
    const m = moment(data[showKey]);
    return m.isValid() ? moment(data[showKey]).format('YYYY-MM-DD HH:mm') : data[showKey];
  }
  return data[showKey];

}
