import 'should';
import sinon from 'sinon';
import React from 'react';
import schemaUtil from 'schema-util';
import Enzyme, { mount } from 'enzyme';
import Adapter from 'enzyme-adapter-react-16';


Enzyme.configure({ adapter: new Adapter() });

import csvUtil from '../lib/util/csv';
import addKey from '../lib/util/addKey';
import ExcelButton from '../lib/fields/excel_button';

const sandbox = sinon.sandbox.create();

describe('excel', function() {
  it('download csv', () => {
    let writeArgs = {};
    sandbox.stub(csvUtil, 'write', (schema, data, title) => {
      writeArgs = { schema, data, title };
    });
    const schema = schemaUtil.schema('Array(foo) { a(a), b(b): Image, c(c): Date }');
    const data = addKey(schemaUtil.mock(schema));
    const props = {
      data,
      schema,
      title: 'bar',
      locale: {
        EXPORT_EXCEL: '下载',
      },
    };

    const field = mount(<ExcelButton {...props} />);
    const itemProps = field.find('ExcelButton').at(0).find('li')
      .at(0)
      .props();
    itemProps.onClick();

    writeArgs.schema.type.should.eql('array');
    writeArgs.schema.description.should.eql('foo');
    writeArgs.data.length.should.eql(2);
  });

  it('upload csv and file size > 3M', () => {
    const schema = schemaUtil.schema('Array(foo) { a(a), b(b): Image, c(c): Date }');
    const data = addKey(schemaUtil.mock(schema));
    const props = {
      data,
      schema,
      title: 'bar',
      locale: {
        EXPORT_EXCEL: '下载',
      },
    };
    const field = mount(<ExcelButton {...props} />);
    const itemProps = field.find('ExcelButton').at(0).find('input')
      .at(0)
      .props();
    itemProps.onChange({
      target: {
        files: {
          item: () => {
            return { size: 1024 * 1024 * 10 };
          },
        },
      },
    });

    field.state().status.should.eql('error');
    field.state().message.should.eql('无法上传超过 3M 的文件');
    field.state().bigFile.should.eql(true);
  });

  it('upload csv normal', () => {
    sandbox.stub(csvUtil, 'read', () => {
      return new Promise(resolve => {
        resolve({});
      });
    });
    sandbox.stub(schemaUtil.csv, 'read', () => {
      return [{
        a: '1', b: '2', c: '2018-12-20 12:12:12',
      }];
    });
    sandbox.stub(global, 'setTimeout', a => { a(); });

    const schema = schemaUtil.schema('Array(foo) { a(a), b(b): Image, c(c): Date }');
    const data = addKey(schemaUtil.mock(schema));
    const props = {
      data,
      schema,
      title: 'bar',
      locale: {
        EXPORT_EXCEL: '下载',
      },
      onUploadSuccess: data => {
        data[0].a.should.eql('1');
        data[0].b.should.eql('2');
        (data[0].c > 0).should.eql(true);
      },
    };
    const field = mount(<ExcelButton {...props} />);
    const itemProps = field.find('ExcelButton').at(0).find('input')
      .at(0)
      .props();
    itemProps.onChange({
      target: {
        files: {
          item: () => {
            return { size: 1024 * 1024 * 1 };
          },
        },
      },
    });
  });
});
