require('should');

import safe from '../lib/util/safe';

describe('util/validate.js', function() {
  it('whiteListDomain is null', function() {
    const schemaStr = '{"backgroundImage":"https://gw.alipayobjects.com/zos/rmsportal/hvpZQsmQzcfytsbDWDrF.png","backgroundColor":"_569BFF","title_zh_Hans_CN":"免费公测","title_en_US":"英文标题","desc_zh_Hans_CN":" 在公测期间，开通均可享受免费试用活动。<br />测试测试","desc_en_US":"英文描述","btns":[{"text_zh_Hans_CN":"申请公测","text_en_US":"英文文字","url":"链接","typeStyle":"default"}]}';
    const result = safe.safeImageUrl(schemaStr);

    result.should.eql(schemaStr);
  });

  describe('not in whiteListDomain', () => {
    it('https protocol', () => {
      const schemaStr = '{"backgroundImage":"https://gw.alipayobjects.com/zos/rmsportal/hvpZQsmQzcfytsbDWDrF.png","backgroundColor":"_569BFF","title_zh_Hans_CN":"免费公测","title_en_US":"英文标题","desc_zh_Hans_CN":" 在公测期间，开通均可享受免费试用活动。<br />测试测试","desc_en_US":"英文描述","btns":[{"text_zh_Hans_CN":"申请公测","text_en_US":"英文文字","url":"链接","typeStyle":"default"}]}';
      const result = safe.safeImageUrl(schemaStr, [ 'x.alipay.com' ]);

      result.should.eql('{"backgroundImage":"https://gw.alipayobjects.com/zos/rmsportal/uFspnShmRpAcxtAjVwlZ.gif","backgroundColor":"_569BFF","title_zh_Hans_CN":"免费公测","title_en_US":"英文标题","desc_zh_Hans_CN":" 在公测期间，开通均可享受免费试用活动。<br />测试测试","desc_en_US":"英文描述","btns":[{"text_zh_Hans_CN":"申请公测","text_en_US":"英文文字","url":"链接","typeStyle":"default"}]}');
    });

    it('http protocol', () => {
      const schemaStr = '{"backgroundImage":"http://gw.alipayobjects.com/zos/rmsportal/hvpZQsmQzcfytsbDWDrF.png","backgroundColor":"_569BFF","title_zh_Hans_CN":"免费公测","title_en_US":"英文标题","desc_zh_Hans_CN":" 在公测期间，开通均可享受免费试用活动。<br />测试测试","desc_en_US":"英文描述","btns":[{"text_zh_Hans_CN":"申请公测","text_en_US":"英文文字","url":"链接","typeStyle":"default"}]}';
      const result = safe.safeImageUrl(schemaStr, [ 'x.alipay.com' ]);

      result.should.eql('{"backgroundImage":"http://gw.alipayobjects.com/zos/rmsportal/uFspnShmRpAcxtAjVwlZ.gif","backgroundColor":"_569BFF","title_zh_Hans_CN":"免费公测","title_en_US":"英文标题","desc_zh_Hans_CN":" 在公测期间，开通均可享受免费试用活动。<br />测试测试","desc_en_US":"英文描述","btns":[{"text_zh_Hans_CN":"申请公测","text_en_US":"英文文字","url":"链接","typeStyle":"default"}]}');
    });

    it('ftp protocol', () => {
      const schemaStr = '{"backgroundImage":"ftp://gw.alipayobjects.com/zos/rmsportal/hvpZQsmQzcfytsbDWDrF.png","backgroundColor":"_569BFF","title_zh_Hans_CN":"免费公测","title_en_US":"英文标题","desc_zh_Hans_CN":" 在公测期间，开通均可享受免费试用活动。<br />测试测试","desc_en_US":"英文描述","btns":[{"text_zh_Hans_CN":"申请公测","text_en_US":"英文文字","url":"链接","typeStyle":"default"}]}';
      const result = safe.safeImageUrl(schemaStr, [ 'x.alipay.com' ]);

      result.should.eql('{"backgroundImage":"ftp://gw.alipayobjects.com/zos/rmsportal/uFspnShmRpAcxtAjVwlZ.gif","backgroundColor":"_569BFF","title_zh_Hans_CN":"免费公测","title_en_US":"英文标题","desc_zh_Hans_CN":" 在公测期间，开通均可享受免费试用活动。<br />测试测试","desc_en_US":"英文描述","btns":[{"text_zh_Hans_CN":"申请公测","text_en_US":"英文文字","url":"链接","typeStyle":"default"}]}');
    });

    it('auto protocol', () => {
      const schemaStr = '{"backgroundImage":"//gw.alipayobjects.com/zos/rmsportal/hvpZQsmQzcfytsbDWDrF.png","backgroundColor":"_569BFF","title_zh_Hans_CN":"免费公测","title_en_US":"英文标题","desc_zh_Hans_CN":" 在公测期间，开通均可享受免费试用活动。<br />测试测试","desc_en_US":"英文描述","btns":[{"text_zh_Hans_CN":"申请公测","text_en_US":"英文文字","url":"链接","typeStyle":"default"}]}';
      const result = safe.safeImageUrl(schemaStr, [ 'x.alipay.com' ]);

      result.should.eql('{"backgroundImage":"//gw.alipayobjects.com/zos/rmsportal/uFspnShmRpAcxtAjVwlZ.gif","backgroundColor":"_569BFF","title_zh_Hans_CN":"免费公测","title_en_US":"英文标题","desc_zh_Hans_CN":" 在公测期间，开通均可享受免费试用活动。<br />测试测试","desc_en_US":"英文描述","btns":[{"text_zh_Hans_CN":"申请公测","text_en_US":"英文文字","url":"链接","typeStyle":"default"}]}');
    });

    it('jpg image', () => {
      const schemaStr = '{"backgroundImage":"ftp://gw.alipayobjects.com/zos/rmsportal/hvpZQsmQzcfytsbDWDrF.jpg","backgroundColor":"_569BFF","title_zh_Hans_CN":"免费公测","title_en_US":"英文标题","desc_zh_Hans_CN":" 在公测期间，开通均可享受免费试用活动。<br />测试测试","desc_en_US":"英文描述","btns":[{"text_zh_Hans_CN":"申请公测","text_en_US":"英文文字","url":"链接","typeStyle":"default"}]}';
      const result = safe.safeImageUrl(schemaStr, [ 'x.alipay.com' ]);

      result.should.eql('{"backgroundImage":"ftp://gw.alipayobjects.com/zos/rmsportal/uFspnShmRpAcxtAjVwlZ.gif","backgroundColor":"_569BFF","title_zh_Hans_CN":"免费公测","title_en_US":"英文标题","desc_zh_Hans_CN":" 在公测期间，开通均可享受免费试用活动。<br />测试测试","desc_en_US":"英文描述","btns":[{"text_zh_Hans_CN":"申请公测","text_en_US":"英文文字","url":"链接","typeStyle":"default"}]}');
    });

    it('jpeg image', () => {
      const schemaStr = '{"backgroundImage":"ftp://gw.alipayobjects.com/zos/rmsportal/hvpZQsmQzcfytsbDWDrF.jpeg","backgroundColor":"_569BFF","title_zh_Hans_CN":"免费公测","title_en_US":"英文标题","desc_zh_Hans_CN":" 在公测期间，开通均可享受免费试用活动。<br />测试测试","desc_en_US":"英文描述","btns":[{"text_zh_Hans_CN":"申请公测","text_en_US":"英文文字","url":"链接","typeStyle":"default"}]}';
      const result = safe.safeImageUrl(schemaStr, [ 'x.alipay.com' ]);

      result.should.eql('{"backgroundImage":"ftp://gw.alipayobjects.com/zos/rmsportal/uFspnShmRpAcxtAjVwlZ.gif","backgroundColor":"_569BFF","title_zh_Hans_CN":"免费公测","title_en_US":"英文标题","desc_zh_Hans_CN":" 在公测期间，开通均可享受免费试用活动。<br />测试测试","desc_en_US":"英文描述","btns":[{"text_zh_Hans_CN":"申请公测","text_en_US":"英文文字","url":"链接","typeStyle":"default"}]}');
    });

    it('gif image', () => {
      const schemaStr = '{"backgroundImage":"ftp://gw.alipayobjects.com/zos/rmsportal/hvpZQsmQzcfytsbDWDrF.gif","backgroundColor":"_569BFF","title_zh_Hans_CN":"免费公测","title_en_US":"英文标题","desc_zh_Hans_CN":" 在公测期间，开通均可享受免费试用活动。<br />测试测试","desc_en_US":"英文描述","btns":[{"text_zh_Hans_CN":"申请公测","text_en_US":"英文文字","url":"链接","typeStyle":"default"}]}';
      const result = safe.safeImageUrl(schemaStr, [ 'x.alipay.com' ]);

      result.should.eql('{"backgroundImage":"ftp://gw.alipayobjects.com/zos/rmsportal/uFspnShmRpAcxtAjVwlZ.gif","backgroundColor":"_569BFF","title_zh_Hans_CN":"免费公测","title_en_US":"英文标题","desc_zh_Hans_CN":" 在公测期间，开通均可享受免费试用活动。<br />测试测试","desc_en_US":"英文描述","btns":[{"text_zh_Hans_CN":"申请公测","text_en_US":"英文文字","url":"链接","typeStyle":"default"}]}');
    });

    it('webp image', () => {
      const schemaStr = '{"backgroundImage":"ftp://gw.alipayobjects.com/zos/rmsportal/hvpZQsmQzcfytsbDWDrF.webp","backgroundColor":"_569BFF","title_zh_Hans_CN":"免费公测","title_en_US":"英文标题","desc_zh_Hans_CN":" 在公测期间，开通均可享受免费试用活动。<br />测试测试","desc_en_US":"英文描述","btns":[{"text_zh_Hans_CN":"申请公测","text_en_US":"英文文字","url":"链接","typeStyle":"default"}]}';
      const result = safe.safeImageUrl(schemaStr, [ 'x.alipay.com' ]);

      result.should.eql('{"backgroundImage":"ftp://gw.alipayobjects.com/zos/rmsportal/uFspnShmRpAcxtAjVwlZ.gif","backgroundColor":"_569BFF","title_zh_Hans_CN":"免费公测","title_en_US":"英文标题","desc_zh_Hans_CN":" 在公测期间，开通均可享受免费试用活动。<br />测试测试","desc_en_US":"英文描述","btns":[{"text_zh_Hans_CN":"申请公测","text_en_US":"英文文字","url":"链接","typeStyle":"default"}]}');
    });

    it('image in richText', () => {
      const schemaStr = '{"text":"<p>&ldquo;看你干的好事！！！&rdquo;&ldquo;我&hellip;&hellip;干嘛了？？？&rdquo;</p><p>&nbsp; &nbsp; &nbsp; &nbsp; 难得在20点前结束工作暴雨天只想赶紧回家葛优躺的宝宝手机突然响了，虎躯一震拿起来，原来是一条信息：</p><p align=\"center\"><img alt=\"说明: https://zos.alipayobjects.com/rmsportal/xvAPqcflSLEIkHc.jpeg\" height=\"452\" src=\"file://localhost/Users/eward/Library/Caches/TemporaryItems/msoclip/0/clip_image002.jpg\" width=\"445\" /></p><p align=\"center\">宝宝怒从心头起！</p><p align=\"center\">好啊，我在苦逼加班赚钱</p><p align=\"center\">你居然背着我做出这样有辱门风的勾当！</p><p align=\"center\">突然，宝宝感觉有些不对</p><p align=\"center\">我不是单身吗？</p><p align=\"center\">什么时候有老婆了呢？</p>"}';
      const result = safe.safeImageUrl(schemaStr, [ 'a.alipayobjects.com' ]);

      result.should.eql('{"text":"<p>&ldquo;看你干的好事！！！&rdquo;&ldquo;我&hellip;&hellip;干嘛了？？？&rdquo;</p><p>&nbsp; &nbsp; &nbsp; &nbsp; 难得在20点前结束工作暴雨天只想赶紧回家葛优躺的宝宝手机突然响了，虎躯一震拿起来，原来是一条信息：</p><p align="center"><img alt="说明: https://gw.alipayobjects.com/zos/rmsportal/uFspnShmRpAcxtAjVwlZ.gif" height="452" src="file://gw.alipayobjects.com/zos/rmsportal/uFspnShmRpAcxtAjVwlZ.gif" width="445" /></p><p align="center">宝宝怒从心头起！</p><p align="center">好啊，我在苦逼加班赚钱</p><p align="center">你居然背着我做出这样有辱门风的勾当！</p><p align="center">突然，宝宝感觉有些不对</p><p align="center">我不是单身吗？</p><p align="center">什么时候有老婆了呢？</p>"}');
    });
  });

  describe('in whiteListDomain', () => {
    it('https domain', () => {
      const schemaStr = '{"backgroundImage":"https://gw.alipayobjects.com/zos/rmsportal/hvpZQsmQzcfytsbDWDrF.png","backgroundColor":"_569BFF","title_zh_Hans_CN":"免费公测","title_en_US":"英文标题","desc_zh_Hans_CN":" 在公测期间，开通均可享受免费试用活动。<br />测试测试","desc_en_US":"英文描述","btns":[{"text_zh_Hans_CN":"申请公测","text_en_US":"英文文字","url":"链接","typeStyle":"default"}]}';
      const result = safe.safeImageUrl(schemaStr, [ 'gw.alipayobjects.com' ]);

      result.should.eql('{"backgroundImage":"https://gw.alipayobjects.com/zos/rmsportal/hvpZQsmQzcfytsbDWDrF.png","backgroundColor":"_569BFF","title_zh_Hans_CN":"免费公测","title_en_US":"英文标题","desc_zh_Hans_CN":" 在公测期间，开通均可享受免费试用活动。<br />测试测试","desc_en_US":"英文描述","btns":[{"text_zh_Hans_CN":"申请公测","text_en_US":"英文文字","url":"链接","typeStyle":"default"}]}');
    });

    it('image with args', () => {
      const schemaStr = '{"backgroundImage":"https://gw.alipayobjects.com/zos/rmsportal/hvpZQsmQzcfytsbDWDrF.png_w4_@12.png?a=111","backgroundColor":"_569BFF","title_zh_Hans_CN":"免费公测","title_en_US":"英文标题","desc_zh_Hans_CN":" 在公测期间，开通均可享受免费试用活动。<br />测试测试","desc_en_US":"英文描述","btns":[{"text_zh_Hans_CN":"申请公测","text_en_US":"英文文字","url":"链接","typeStyle":"default"}]}';
      const result = safe.safeImageUrl(schemaStr, [ 'gw.alipayobjects.com' ]);

      result.should.eql('{"backgroundImage":"https://gw.alipayobjects.com/zos/rmsportal/hvpZQsmQzcfytsbDWDrF.png_w4_@12.png?a=111","backgroundColor":"_569BFF","title_zh_Hans_CN":"免费公测","title_en_US":"英文标题","desc_zh_Hans_CN":" 在公测期间，开通均可享受免费试用活动。<br />测试测试","desc_en_US":"英文描述","btns":[{"text_zh_Hans_CN":"申请公测","text_en_US":"英文文字","url":"链接","typeStyle":"default"}]}');
    });

    it('image in richText', () => {
      const schemaStr = '{"text":"<p>&ldquo;看你干的好事！！！&rdquo;&ldquo;我&hellip;&hellip;干嘛了？？？&rdquo;</p><p>&nbsp; &nbsp; &nbsp; &nbsp; 难得在20点前结束工作暴雨天只想赶紧回家葛优躺的宝宝手机突然响了，虎躯一震拿起来，原来是一条信息：</p><p align=\"center\"><img alt=\"说明: https://zos.alipayobjects.com/rmsportal/xvAPqcflSLEIkHc.jpeg\" height=\"452\" src=\"https://zos.alipayobjects.com/rmsportal/xvAPqcflSLEIkHc.jpeg\" width=\"445\" /></p><p align=\"center\">宝宝怒从心头起！</p><p align=\"center\">好啊，我在苦逼加班赚钱</p><p align=\"center\">你居然背着我做出这样有辱门风的勾当！</p><p align=\"center\">突然，宝宝感觉有些不对</p><p align=\"center\">我不是单身吗？</p><p align=\"center\">什么时候有老婆了呢？</p>"}';
      const result = safe.safeImageUrl(schemaStr, [ 'zos.alipayobjects.com' ]);

      result.should.eql('{"text":"<p>&ldquo;看你干的好事！！！&rdquo;&ldquo;我&hellip;&hellip;干嘛了？？？&rdquo;</p><p>&nbsp; &nbsp; &nbsp; &nbsp; 难得在20点前结束工作暴雨天只想赶紧回家葛优躺的宝宝手机突然响了，虎躯一震拿起来，原来是一条信息：</p><p align=\"center\"><img alt=\"说明: https://zos.alipayobjects.com/rmsportal/xvAPqcflSLEIkHc.jpeg\" height=\"452\" src=\"https://zos.alipayobjects.com/rmsportal/xvAPqcflSLEIkHc.jpeg\" width=\"445\" /></p><p align=\"center\">宝宝怒从心头起！</p><p align=\"center\">好啊，我在苦逼加班赚钱</p><p align=\"center\">你居然背着我做出这样有辱门风的勾当！</p><p align=\"center\">突然，宝宝感觉有些不对</p><p align=\"center\">我不是单身吗？</p><p align=\"center\">什么时候有老婆了呢？</p>"}');
    });
  });

});
