require('should');
const UploaderValidator = require('../lib/util/uploaderValidator');

describe('util/uploaderValidator.js', function() {

  // 宽度要求
  it('validateImageDimension width', function() {
    const required = {
      width: 640,
    };

    // 偏大
    let real = {
      width: 750,
      height: 100,
    };
    let validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.equal(`宽度为 ${required.width}px`);

    // 偏小
    real = {
      width: 6000,
      height: 100,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.equal(`宽度为 ${required.width}px`);

    // 一样
    real = {
      width: 640,
      height: 100,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(true);
    validate.message.should.equal('');
  });

  // 高度要求
  it('validateImageDimension height', function() {
    const required = {
      height: 200,
    };

    // 偏大
    let real = {
      width: 750,
      height: 300,
    };
    let validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.equal(`高度为 ${required.height}px`);

    // 偏小
    real = {
      width: 750,
      height: 100,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.equal(`高度为 ${required.height}px`);

    // 一样
    real = {
      width: 750,
      height: 200,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(true);
    validate.message.should.equal('');
  });

  // 最大宽度要求
  it('validateImageDimension maxWidth', function() {
    const required = {
      maxWidth: 640,
    };

    // 偏大
    let real = {
      width: 750,
      height: 100,
    };
    let validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.equal(`宽度不超过 ${required.maxWidth}px`);

    // 偏小
    real = {
      width: 600,
      height: 100,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(true);
    validate.message.should.equal('');

    // 一样
    real = {
      width: 640,
      height: 100,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(true);
    validate.message.should.equal('');
  });

  // 最大高度要求
  it('validateImageDimension maxHeight', function() {
    const required = {
      maxHeight: 100,
    };

    // 偏大
    let real = {
      width: 750,
      height: 200,
    };
    let validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.equal(`高度不超过 ${required.maxHeight}px`);

    // 偏小
    real = {
      width: 750,
      height: 50,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(true);
    validate.message.should.equal('');

    // 一样
    real = {
      width: 750,
      height: 100,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(true);
    validate.message.should.equal('');
  });

  // 宽高要求
  it('validateImageDimension width & height', function() {
    const required = {
      width: 640,
      height: 100,
    };

    // 宽度偏大
    let real = {
      width: 750,
      height: 100,
    };
    let validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.equal(`尺寸为 ${required.width}x${required.height}`);

    // 高度偏大
    real = {
      width: 640,
      height: 200,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.equal(`尺寸为 ${required.width}x${required.height}`);

    // 宽度和高度都偏大
    real = {
      width: 750,
      height: 200,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.equal(`尺寸为 ${required.width}x${required.height}`);

    // 宽度偏小
    real = {
      width: 600,
      height: 100,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.equal(`尺寸为 ${required.width}x${required.height}`);

    // 高度偏小
    real = {
      width: 640,
      height: 50,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.equal(`尺寸为 ${required.width}x${required.height}`);

    // 宽度和高度都偏小
    real = {
      width: 600,
      height: 50,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.equal(`尺寸为 ${required.width}x${required.height}`);

    // 宽度和高度一样
    real = {
      width: 640,
      height: 100,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(true);
    validate.message.should.equal('');
  });

  // 最大宽高要求
  it('validateImageDimension maxWidth & maxHeight', function() {
    const required = {
      maxWidth: 640,
      maxHeight: 100,
    };

    // 宽度偏大
    let real = {
      width: 750,
      height: 100,
    };
    let validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.equal(`尺寸不超过 ${required.maxWidth}x${required.maxHeight}`);

    // 高度偏大
    real = {
      width: 640,
      height: 200,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.equal(`尺寸不超过 ${required.maxWidth}x${required.maxHeight}`);

    // 宽度和高度都偏大
    real = {
      width: 750,
      height: 200,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.equal(`尺寸不超过 ${required.maxWidth}x${required.maxHeight}`);

    // 宽度偏小
    real = {
      width: 600,
      height: 100,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(true);
    validate.message.should.equal('');

    // 高度偏小
    real = {
      width: 640,
      height: 50,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(true);
    validate.message.should.equal('');

    // 宽度和高度都偏小
    real = {
      width: 600,
      height: 50,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(true);
    validate.message.should.equal('');

    // 宽度和高度一样
    real = {
      width: 640,
      height: 100,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(true);
    validate.message.should.equal('');
  });

  // 宽度和最大高度要求
  it('validateImageDimension width & maxHeight', function() {
    const required = {
      width: 640,
      maxHeight: 100,
    };

    // 宽度偏大
    let real = {
      width: 750,
      height: 100,
    };
    let validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.containEql(`宽度为 ${required.width}px`);

    // 高度偏大
    real = {
      width: 640,
      height: 200,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.containEql(`高度不超过 ${required.maxHeight}px`);

    // 宽度和高度都偏大
    real = {
      width: 750,
      height: 200,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.containEql(`宽度为 ${required.width}px`);
    validate.message.should.containEql(`高度不超过 ${required.maxHeight}px`);

    // 宽度偏小
    real = {
      width: 600,
      height: 100,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.containEql(`宽度为 ${required.width}px`);

    // 高度偏小
    real = {
      width: 640,
      height: 50,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(true);
    validate.message.should.equal('');

    // 宽度和高度都偏小
    real = {
      width: 600,
      height: 50,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.containEql(`宽度为 ${required.width}px`);

    // 宽度和高度一样
    real = {
      width: 640,
      height: 100,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(true);
    validate.message.should.equal('');
  });

  // 宽度和最大高度要求
  it('validateImageDimension maxWidth & height', function() {
    const required = {
      maxWidth: 640,
      height: 100,
    };

    // 宽度偏大
    let real = {
      width: 750,
      height: 100,
    };
    let validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.containEql(`宽度不超过 ${required.maxWidth}px`);

    // 高度偏大
    real = {
      width: 640,
      height: 200,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.containEql(`高度为 ${required.height}px`);

    // 宽度和高度都偏大
    real = {
      width: 750,
      height: 200,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.containEql(`宽度不超过 ${required.maxWidth}px`);
    validate.message.should.containEql(`高度为 ${required.height}px`);

    // 宽度偏小
    real = {
      width: 600,
      height: 100,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(true);
    validate.message.should.equal('');

    // 高度偏小
    real = {
      width: 640,
      height: 50,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.containEql(`高度为 ${required.height}px`);

    // 宽度和高度都偏小
    real = {
      width: 600,
      height: 50,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(false);
    validate.message.should.containEql(`高度为 ${required.height}px`);

    // 宽度和高度一样
    real = {
      width: 640,
      height: 100,
    };
    validate = UploaderValidator.validateImageDimension(required, real);
    validate.result.should.equal(true);
    validate.message.should.equal('');
  });

  // 宽度和最大宽度要求
  it('validateImageDimension width & maxWidth', function() {
    const required = {
      width: 640,
      maxWidth: 750,
    };
    const requiredShadow = {
      width: 640,
    };

    // 说明不管校验什么值，都是以 width 的为准，maxWidth 被忽略
    const validateProcess = function(required, requiredShadow, real) {
      const validate = UploaderValidator.validateImageDimension(required, real);
      const validateShadow = UploaderValidator.validateImageDimension(requiredShadow, real);
      validate.result.should.equal(validateShadow.result);
      validate.message.should.equal(validateShadow.message);
    };

    // 比最大宽度偏大
    let real = {
      width: 751,
      height: 100,
    };
    validateProcess(required, requiredShadow, real);

    // 比最大宽度偏小
    real = {
      width: 749,
      height: 100,
    };
    validateProcess(required, requiredShadow, real);

    // 跟最大宽度一样
    real = {
      width: 750,
      height: 100,
    };
    validateProcess(required, requiredShadow, real);

    // 比宽度偏大
    real = {
      width: 641,
      height: 100,
    };
    validateProcess(required, requiredShadow, real);

    // 比宽度偏小
    real = {
      width: 639,
      height: 100,
    };
    validateProcess(required, requiredShadow, real);

    // 跟宽度一样
    real = {
      width: 640,
      height: 100,
    };
    validateProcess(required, requiredShadow, real);
  });

  // 宽度和最大宽度要求
  it('validateImageDimension height & maxHeight', function() {
    const required = {
      height: 100,
      maxHeight: 150,
    };
    const requiredShadow = {
      height: 100,
    };

    // 说明不管校验什么值，都是以 width 的为准，maxWidth 被忽略
    const validateProcess = function(required, requiredShadow, real) {
      const validate = UploaderValidator.validateImageDimension(required, real);
      const validateShadow = UploaderValidator.validateImageDimension(requiredShadow, real);
      validate.result.should.equal(validateShadow.result);
      validate.message.should.equal(validateShadow.message);
    };

    // 比最大宽度偏大
    let real = {
      width: 751,
      height: 151,
    };
    validateProcess(required, requiredShadow, real);

    // 比最大宽度偏小
    real = {
      width: 749,
      height: 149,
    };
    validateProcess(required, requiredShadow, real);

    // 跟最大宽度一样
    real = {
      width: 750,
      height: 150,
    };
    validateProcess(required, requiredShadow, real);

    // 比宽度偏大
    real = {
      width: 641,
      height: 101,
    };
    validateProcess(required, requiredShadow, real);

    // 比宽度偏小
    real = {
      width: 639,
      height: 99,
    };
    validateProcess(required, requiredShadow, real);

    // 跟宽度一样
    real = {
      width: 640,
      height: 100,
    };
    validateProcess(required, requiredShadow, real);
  });

  // 校验尺寸和容量的关系
  it('validateImageSize', function() {
    const dimension = {
      width: 500,
      height: 400,
    };
    const ratio = 0.4;
    const limitSize = Number((dimension.width * dimension.height * ratio / 1024).toFixed(2));

    // 容量大于要求
    let size = parseInt(dimension.width * dimension.height * ratio + 1, 10);
    let validate = UploaderValidator.validateImageSize(dimension, size);
    validate.result.should.equal(false);
    validate.message.should.equal(`不超过 ${limitSize}KB`);

    // 容量小于要求
    size = parseInt(dimension.width * dimension.height * ratio - 1, 10);
    validate = UploaderValidator.validateImageSize(dimension, size);
    validate.result.should.equal(true);
    validate.message.should.equal('');

    // 容量相等
    size = parseInt(dimension.width * dimension.height * ratio, 10);
    validate = UploaderValidator.validateImageSize(dimension, size);
    validate.result.should.equal(true);
    validate.message.should.equal('');

    validate = UploaderValidator.validateImageSize({}, size);
    validate.result.should.equal(false);
  });

  describe('validate image max size', function() {
    it('have no meta', function() {
      const validate = UploaderValidator.validateImageMaxSize({}, {});
      validate.result.should.equal(true);
    });
    it('max size is not number', function() {
      const validate = UploaderValidator.validateImageMaxSize({}, { meta: { maxSize: '' } });
      validate.result.should.equal(true);
    });
    it('file size lt max size', function() {
      const validate = UploaderValidator.validateImageMaxSize({ size: 1000 }, { meta: { maxSize: '1' } });
      validate.result.should.equal(true);
    });
    it('file size gt max size', function() {
      const validate = UploaderValidator.validateImageMaxSize({ size: 10000 }, { meta: { maxSize: '1' } });
      validate.result.should.equal(false);
    });
  });

});
