require('should');
import * as locale from '../lib/i18n/zh_cn';

const validate = require('../lib/util/validate');

describe('util/validate.js', function() {
  it('meta is null', function() {
    const result = validate('xx', null);
    result.should.eql('');
  });

  it('min length', function() {
    const result = validate('x', {
      minLength: 10,
    }, null, locale);
    result.should.containEql('输入内容要求不得少于');
  });

  it('zero length', function() {
    const result = validate('', {
      minLength: 10,
    }, null, locale);
    result.should.containEql('输入内容要求不得少于');
  });

  it('max length', function() {
    const result = validate('this-is-a-lonng-text', {
      maxLength: 10,
    }, null, locale);
    result.should.containEql('10');
  });

  it('regExp without errorMsg', function() {
    const result = validate('xx', { regExp: '/\d+/' }, null, locale);
    result.should.eql('格式错误');
  });

  it('regExp with errorMsg', function() {
    const result = validate('xx', { regExp: '/\d+/', errorMsg: 'error-message' }, null, locale);
    result.should.eql('error-message');
  });

  it('number', function() {
    const result = validate(12, { max: 11 }, 'number', locale);
    result.should.containEql('11');

    const result1 = validate(10, { min: 12 }, 'number', locale);
    result1.should.containEql('12');
  });
});
