// 正式环境
const webpack = require('atool-build/lib/webpack');

module.exports = function(webpackConfig) {
  webpackConfig.externals = Object.assign({}, webpackConfig.externals, {
    react: 'React',
    'react-dom': 'ReactDOM',
  });

  webpackConfig.plugins.some(function(plugin, i) {
    if (plugin.constructor.name === 'CommonsChunkPlugin') {
      webpackConfig.plugins.splice(i, 1);
      return true;
    }
  });
  // https://github.com/webpack/webpack/issues/1866
  webpackConfig.babel.plugins.push([require.resolve('babel-plugin-import'), {
    libraryName: 'antd',
    style: 'less',
  }]);

  if (process.env.NODE_ENV !== 'development') {
    webpackConfig.plugins.push(new webpack.optimize.UglifyJsPlugin({
      output: {
        ascii_only: true,
      },
      compress: {
        warnings: false,
      },
    }));
  } else {
    webpackConfig.babel.plugins.push([ require.resolve('babel-plugin-react-transform'), {
      transforms: [{
        transform: 'react-transform-hmr',
        // if you use React Native, pass "react-native" instead:
        imports: [ 'react' ],
        // this is important for Webpack HMR:
        locals: [ 'module' ],
      }],
    }]);

    webpackConfig.module.loaders.map(mod => {
      if (!mod.loader) {
        return;
      }

      if (mod.loader.includes('extract-text-webpack-plugin')) {
        mod.loader = `css-hot-loader!${mod.loader}`;
      }
    });
  }

  return webpackConfig;
};
